nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Misc0

Struct Misc0 

#[repr(transparent)]
pub struct Misc0(pub u32);
Miscellaneous Register 0

Tuple Fields

0: u32

Implementations

Source

impl Misc0

pub const fn reftop_pwd(&self) -> bool

Control bit to power-down the analog bandgap reference circuitry

pub const fn set_reftop_pwd(&mut self, val: bool)

Control bit to power-down the analog bandgap reference circuitry

pub const fn reftop_selfbiasoff(&self) -> Misc0ReftopSelfbiasoff

Control bit to disable the self-bias circuit in the analog bandgap

pub const fn set_reftop_selfbiasoff(&mut self, val: Misc0ReftopSelfbiasoff)

Control bit to disable the self-bias circuit in the analog bandgap

pub const fn reftop_vbgadj(&self) -> Misc0ReftopVbgadj

Not related to oscillator.

pub const fn set_reftop_vbgadj(&mut self, val: Misc0ReftopVbgadj)

Not related to oscillator.

pub const fn reftop_vbgup(&self) -> bool

Status bit that signals the analog bandgap voltage is up and stable

pub const fn set_reftop_vbgup(&mut self, val: bool)

Status bit that signals the analog bandgap voltage is up and stable

pub const fn stop_mode_config(&self) -> Misc0StopModeConfig

Configure the analog behavior in stop mode. Not related to oscillator.

pub const fn set_stop_mode_config(&mut self, val: Misc0StopModeConfig)

Configure the analog behavior in stop mode. Not related to oscillator.

pub const fn discon_high_snvs(&self) -> Misc0DisconHighSnvs

This bit controls a switch from VDD_HIGH_IN to VDD_SNVS_IN.

pub const fn set_discon_high_snvs(&mut self, val: Misc0DisconHighSnvs)

This bit controls a switch from VDD_HIGH_IN to VDD_SNVS_IN.

pub const fn osc_i(&self) -> Misc0OscI

This field determines the bias current in the 24MHz oscillator

pub const fn set_osc_i(&mut self, val: Misc0OscI)

This field determines the bias current in the 24MHz oscillator

pub const fn osc_xtalok(&self) -> bool

Status bit that signals that the output of the 24-MHz crystal oscillator is stable

pub const fn set_osc_xtalok(&mut self, val: bool)

Status bit that signals that the output of the 24-MHz crystal oscillator is stable

pub const fn osc_xtalok_en(&self) -> bool

This bit enables the detector that signals when the 24MHz crystal oscillator is stable.

pub const fn set_osc_xtalok_en(&mut self, val: bool)

This bit enables the detector that signals when the 24MHz crystal oscillator is stable.

pub const fn clkgate_ctrl(&self) -> Misc0ClkgateCtrl

This bit allows disabling the clock gate (always ungated) for the xtal 24MHz clock that clocks the digital logic in the analog block

pub const fn set_clkgate_ctrl(&mut self, val: Misc0ClkgateCtrl)

This bit allows disabling the clock gate (always ungated) for the xtal 24MHz clock that clocks the digital logic in the analog block

pub const fn clkgate_delay(&self) -> Misc0ClkgateDelay

This field specifies the delay between powering up the XTAL 24MHz clock and releasing the clock to the digital logic inside the analog block

pub const fn set_clkgate_delay(&mut self, val: Misc0ClkgateDelay)

This field specifies the delay between powering up the XTAL 24MHz clock and releasing the clock to the digital logic inside the analog block

pub const fn rtc_xtal_source(&self) -> Misc0RtcXtalSource

This field indicates which chip source is being used for the rtc clock.

pub const fn set_rtc_xtal_source(&mut self, val: Misc0RtcXtalSource)

This field indicates which chip source is being used for the rtc clock.

pub const fn xtal_24m_pwd(&self) -> bool

This field powers down the 24M crystal oscillator if set true.

pub const fn set_xtal_24m_pwd(&mut self, val: bool)

This field powers down the 24M crystal oscillator if set true.

pub const fn vid_pll_prediv(&self) -> Misc0VidPllPrediv

Predivider for the source clock of the PLL’s. Not related to oscillator.

pub const fn set_vid_pll_prediv(&mut self, val: Misc0VidPllPrediv)

Predivider for the source clock of the PLL’s. Not related to oscillator.