nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

OscConfig0

Struct OscConfig0 

#[repr(transparent)]
pub struct OscConfig0(pub u32);
XTAL OSC Configuration 0 Register

Tuple Fields

0: u32

Implementations

Source

impl OscConfig0

pub const fn start(&self) -> bool

Start/stop bit for the RC tuning calculation logic. If stopped the tuning logic is reset.

pub const fn set_start(&mut self, val: bool)

Start/stop bit for the RC tuning calculation logic. If stopped the tuning logic is reset.

pub const fn enable(&self) -> bool

Enables the tuning logic to calculate new RC tuning values

pub const fn set_enable(&mut self, val: bool)

Enables the tuning logic to calculate new RC tuning values

pub const fn bypass(&self) -> bool

Bypasses any calculated RC tuning value and uses the programmed register value.

pub const fn set_bypass(&mut self, val: bool)

Bypasses any calculated RC tuning value and uses the programmed register value.

pub const fn invert(&self) -> bool

Invert the stepping of the calculated RC tuning value.

pub const fn set_invert(&mut self, val: bool)

Invert the stepping of the calculated RC tuning value.

pub const fn rc_osc_prog(&self) -> u8

RC osc. tuning values.

pub const fn set_rc_osc_prog(&mut self, val: u8)

RC osc. tuning values.

pub const fn hyst_plus(&self) -> u8

Positive hysteresis value

pub const fn set_hyst_plus(&mut self, val: u8)

Positive hysteresis value

pub const fn hyst_minus(&self) -> u8

Negative hysteresis value

pub const fn set_hyst_minus(&mut self, val: u8)

Negative hysteresis value

pub const fn rc_osc_prog_cur(&self) -> u8

The current tuning value in use.

pub const fn set_rc_osc_prog_cur(&mut self, val: u8)

The current tuning value in use.